:orphan:


Security
========

References
----------

-  `A New Approach to IoT
   Security <https://www.pubnub.com/static/papers/IoT_Security_Whitepaper_Final.pdf>`__
-  `Inside-Out Security for the
   IoT <https://www.altera.com/solutions/technology/system-design/articles/_2014/security-iot.smartphone.highResolutionDisplay.html>`__
-  `TUV SUD IoT Honeynet Project (in
   German) <https://www.pressebox.de/pressemitteilung/tuev-sued-ag/Potenzielle-Angreifer-sind-ueberall/boxid/748729>`__
